****************************
scikit-image |version| docs
****************************

scikit-image is an image processing toolbox for SciPy_. View the
`release notes <release_notes.html>`_ for |version|.

.. _SciPy: https://www.scipy.org


Sections
========

.. toctree::
   :hidden:

   overview
   api/api
   install
   user_guide
   glossary
   contribute
   license
   auto_examples/index
   release_notes
   core_developer
   skips/index
   values
   conduct/code_of_conduct

.. list-table::
   :class: contentstable

   * - `Overview <overview.html>`_

       Introduction to scikit-image.

     - `API Reference <api/api.html>`_ (`changes <release_notes.html>`_)

       Documentation for the functions included in scikit-image.

   * - `Mission Statement <values.html>`_

       Our mission, vision, and values.

     - `Governance <skips/1-governance.html>`_

       How decisions are made in scikit-image.

   * - `Installation <install.html>`_

       How to install scikit-image.

     - `User Guide <user_guide.html>`_

       Usage guidelines.

   * - `Glossary <glossary.html>`_

       Definitions of common terms.

     - `Contribute <contribute.html>`_

       Take part in development.  Core developers, please `read your guide
       <core_developer.html>`_.


   * - `Gallery <auto_examples/index.html>`_

       Introductory generic and domain-specific examples.

     - `License Info <license.html>`_

       Conditions on the use and redistribution of this package.

   * - `SKIPs <skips/index.html>`_

       **s**\ ci\ **k**\ it-\ **i**\ mage **p**\ roposals, documents describing major changes to the
       library.

     - `Code of Conduct <conduct/code_of_conduct.html>`_

       Community interaction guidelines.


Indices
=======

.. list-table::
   :class: contentstable

   * - :ref:`search`

       Search this documentation.

     - :ref:`genindex`

       All functions, classes, terms.
